==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/lang/en/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
setlocale(LC_ALL,'en_EN@utf-8','en_EN');
$lang = array(
'total'=>'Total',
'login_valid_for'=>'Authentication Time Remaining',
'profile_view'=>'Profile View',
'edit'=>'Edit',
'delete'=>'Delete',
'group'=>'User Group',
'registration_date'=>'Registered Since',
'post_count'=>'Posts',
'post_count_hint'=>'This value is a best guess and may differ from reality.',
'query_for'=>'Search Users',
'sort_by'=>'Sort By',
'order_by'=>'Order',
'search_posts_by_user'=>'Find Postings',
'ascending'=>'Ascending',
'descending'=>'Descending',
'page'=>'Page',
'name'=>'Name',
'guest'=>'Guest',
'group_alias_guest'=>'Unregistered',
'group_alias_user'=>'Member',
'group_alias_mod'=>'Moderator',
'group_alias_exec'=>'Executive',
'group_alias_root'=>'Super-User',
'home'=>'Home',
'login'=>'Login',
'logout'=>'Logout',
'register'=>'Register',
'my_profile'=>'My Profile',
'search'=>'Search',
'member_list'=>'Member List',
'help'=>'Help',
'standard_panel'=>'User Area',
'moderation_panel'=>'Moderation Area',
'executive_panel'=>'Executive Area',
'user_request'=>'User Request',
'overview'=>'Overview',
'welcome'=>'Welcome',
'user'=>'User',
'select_user'=>'Select User',
'ap_mod'=>'Moderators',
'ap_exec'=>'Executives',
'ap_owner'=>'Owner',
'username'=>'Username',
'password'=>'Password',
'mail_address'=>'E-Mail Address',
'success'=>'Success',
'fail'=>'Failure',
'replies'=>'Replies',
'last_reply'=>'Last Reply',
'warning_level'=>'Warning Level',
'warning_level_none'=>'No warnings issued so far',
'warning_level_low'=>'Has been warned once',
'warning_level_medium'=>'Needs attention on further misbehaviour',
'warning_level_high'=>'Causes severe trouble by violating rules',
'warning_high'=>'You violated our rules multiple times and reached the highest warning level!',
'prefix_support_request'=>'Support Request',
'prefix_staff_only'=>'To Staff only',
'prefix_moderator_only'=>'To Moderator only',
'prefix_executive_only'=>'To Executive only',
'prefix_announcement'=>'Announcement',
'redirection'=>'Redirection',
'click_here_for_redirection'=>'Please click here, if you are not forwarded automatically...',
'go_one_step_back'=>'Please click here to go one step back...',
'javascript_hint'=>'Please enable <em>Javascript</em> in your browser to get full usability on our forums! Basic functions can
be used without it, if you are concerned about your security. To enable it, please have a look at your browser manual how to do
this. Usually it can be found in &quot;Options&quot; or &quot;Settings&quot;.',
'invalid_form_input'=>'Please verify your inputs as some were rejected!',
'running_action_denied_by_acl'=>'You are not allowed to perform this action as you were rejected by access control list',
'an_error_occured'=>'An error has occured',
'access_denied'=>'Access Denied',
'file_not_found'=>'File Not Found',
'clear'=>'Clear',
'stage'=>'Do what?',
'preview'=>'Preview',
'submit'=>'Submit',
'reset_form'=>'Reset',
'back_to_topic'=>'Back to topic',
'enable'=>'Enable',
'disable'=>'Disable',
'visible'=>'Visible',
'hidden'=>'Hidden',
'allow'=>'Allow',
'accept'=>'Accept',
'deny'=>'Deny',
'new'=>'New',
'by'=>'by',
'all'=>'all',
'none'=>'none',
'on'=>'on',
'default'=>'default',
'yes'=>'yes',
'no'=>'no',
'ascending'=>'Ascending',
'descending'=>'Descending',
'today'=>'Today',
'yesterday'=>'Yesterday',
'year'=>'Year',
'month'=>'Month',
'day'=>'Day',
'days'=>'Days',
'hour'=>'Hour',
'hours'=>'Hours',
'minute'=>'Minute',
'minutes'=>'Minutes',
'second'=>'Second',
'seconds'=>'Seconds',
'subject'=>'Subject',
'message'=>'Message',
'date'=>'Date',
'tags'=>'Tags',
'options'=>'Options',
'rating'=>'Rating',
'currently_none'=>'currently none',
'be_careful_on_external_content'=>'Be careful on external content!',
'imprint_and_privacy'=>'Imprint and Privacy Statement',
'all_times_are'=>'All times are',
'really_logout'=>'Would you really like to logout?',
'please_confirm_your_selection'=>'Please confirm your request to irrevocably delete the selected items...',
'please_confirm_reverting'=>'Please confirm you really want to revert to this revision?',
'requires_executive_flag'=>'You must be in a user group having executive permission to do this.',
'no_members_found'=>'No members are found on your query...',
'no_valid_id'=>'Your selected ID is invalid!',
'fun_message_1'=>'You forgot to say the &quot;MAGICAL WORD&quot;...',
'fun_message_2'=>'I think I am bothered of you...',
'fun_message_3'=>'Can`t you see I am busy?',
'fun_message_4'=>'I beg your pardon?',
'fun_message_5'=>'No, I am not going to do that!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Do not disturb me now, you *&quot;\$/(=!',
'fun_message_8'=>'*sigh*'
);
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/lang/en/core.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
setlocale(LC_ALL,'en_EN@utf-8','en_EN');
$lang = array(
'total'=>'Total',
'login_valid_for'=>'Authentication Time Remaining',
'profile_view'=>'Profile View',
'edit'=>'Edit',
'delete'=>'Delete',
'group'=>'User Group',
'registration_date'=>'Registered Since',
'post_count'=>'Posts',
'post_count_hint'=>'This value is a best guess and may differ from reality.',
'query_for'=>'Search Users',
'sort_by'=>'Sort By',
'order_by'=>'Order',
'search_posts_by_user'=>'Find Postings',
'ascending'=>'Ascending',
'descending'=>'Descending',
'page'=>'Page',
'name'=>'Name',
'guest'=>'Guest',
'group_alias_guest'=>'Unregistered',
'group_alias_user'=>'Member',
'group_alias_mod'=>'Moderator',
'group_alias_exec'=>'Executive',
'group_alias_root'=>'Super-User',
'home'=>'Home',
'login'=>'Login',
'logout'=>'Logout',
'register'=>'Register',
'my_profile'=>'My Profile',
'search'=>'Search',
'member_list'=>'Member List',
'help'=>'Help',
'standard_panel'=>'User Area',
'moderation_panel'=>'Moderation Area',
'executive_panel'=>'Executive Area',
'user_request'=>'User Request',
'overview'=>'Overview',
'welcome'=>'Welcome',
'user'=>'User',
'select_user'=>'Select User',
'ap_mod'=>'Moderators',
'ap_exec'=>'Executives',
'ap_owner'=>'Owner',
'username'=>'Username',
'password'=>'Password',
'mail_address'=>'E-Mail Address',
'success'=>'Success',
'fail'=>'Failure',
'replies'=>'Replies',
'last_reply'=>'Last Reply',
'warning_level'=>'Warning Level',
'warning_level_none'=>'No warnings issued so far',
'warning_level_low'=>'Has been warned once',
'warning_level_medium'=>'Needs attention on further misbehaviour',
'warning_level_high'=>'Causes severe trouble by violating rules',
'warning_high'=>'You violated our rules multiple times and reached the highest warning level!',
'prefix_support_request'=>'Support Request',
'prefix_staff_only'=>'To Staff only',
'prefix_moderator_only'=>'To Moderator only',
'prefix_executive_only'=>'To Executive only',
'prefix_announcement'=>'Announcement',
'redirection'=>'Redirection',
'click_here_for_redirection'=>'Please click here, if you are not forwarded automatically...',
'go_one_step_back'=>'Please click here to go one step back...',
'javascript_hint'=>'Please enable <em>Javascript</em> in your browser to get full usability on our forums! Basic functions can
be used without it, if you are concerned about your security. To enable it, please have a look at your browser manual how to do
this. Usually it can be found in "Options" or "Settings".',
'invalid_form_input'=>'Please verify your inputs as some were rejected!',
'running_action_denied_by_acl'=>'You are not allowed to perform this action as you were rejected by access control list',
'an_error_occured'=>'An error has occured',
'explain_error_message'=>'Usually this happens because you are not logged with your user account. Another reason may be
that your authentication became invalid. Then you should reload the page in your browser. The forum will
ask you to renew it. Last but not least you may simply just have no permission to access that given area.',
'access_denied'=>'Access Denied',
'file_not_found'=>'File Not Found',
'clear'=>'Clear',
'stage'=>'Do what?',
'preview'=>'Preview',
'submit'=>'Submit',
'back_to_topic'=>' Back to Topic',
'enable'=>'Enable',
'disable'=>'Disable',
'visible'=>'Visible',
'hidden'=>'Hidden',
'allow'=>'Allow',
'accept'=>'Accept',
'deny'=>'Deny',
'new'=>'New',
'by'=>'by',
'all'=>'all',
'none'=>'none',
'on'=>'on',
'default'=>'default',
'yes'=>'yes',
'no'=>'no',
'ascending'=>'Ascending',
'descending'=>'Descending',
'today'=>'Today',
'yesterday'=>'Yesterday',
'year'=>'Year',
'month'=>'Month',
'day'=>'Day',
'days'=>'Days',
'hour'=>'Hour',
'hours'=>'Hours',
'minute'=>'Minute',
'minutes'=>'Minutes',
'second'=>'Second',
'seconds'=>'Seconds',
'expired'=>'expired',
'subject'=>'Subject',
'message'=>'Message',
'date'=>'Date',
'tags'=>'Tags',
'options'=>'Options',
'rating'=>'Rating',
'currently_none'=>'currently none',
'be_careful_on_external_content'=>'Be careful on external content!',
'imprint_and_privacy'=>'Imprint and Privacy Statement',
'all_times_are'=>'All times are',
'really_logout'=>'Would you really like to logout?',
'please_confirm_your_selection'=>'Please confirm your request to irrevocably delete the selected items...',
'please_confirm_reverting'=>'Please confirm you really want to revert to this revision?',
'requires_executive_flag'=>'You must be in a user group having executive permission to do this.',
'no_members_found'=>'No members are found on your query...',
'no_valid_id'=>'Your selected ID is invalid!',
'transaction_number_invalid'=>'You have not pass the correct transaction number!',
'action_has_not_committed_transaction'=>'Proccess aborted due to open transaction!',
'fun_message_1'=>'You forgot to say the "MAGICAL WORD"...',
'fun_message_2'=>'I think I am bothered of you...',
'fun_message_3'=>'Can`t you see I am busy?',
'fun_message_4'=>'I beg your pardon?',
'fun_message_5'=>'No, I am not going to do that!',
'fun_message_6'=>'The same procedure as every year, James!',
'fun_message_7'=>'Do not disturb me now, you *"\$/(=!',
'fun_message_8'=>'*sigh*'
);
?>
